package de.fhhannover.inform.trust.ifmapj.channel;

import java.io.InputStream;

import javax.net.ssl.KeyManager;
import javax.net.ssl.TrustManager;

import de.fhhannover.inform.trust.ifmapj.exception.EndSessionException;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapErrorResult;
import de.fhhannover.inform.trust.ifmapj.exception.IfmapException;
import de.fhhannover.inform.trust.ifmapj.exception.InitializationException;
import de.fhhannover.inform.trust.ifmapj.messages.PollRequest;
import de.fhhannover.inform.trust.ifmapj.messages.PollResult;

public class ArcImpl extends Channel implements ARC {
	
	/**
	 * {@link SSRC} object used to create this {@link ARC} instance
	 */
	private final SSRC mSsrc;
	
	ArcImpl(SSRC ssrc, String url, KeyManager[] kms, TrustManager[] tms) 
			throws InitializationException {
		super(url, kms, tms);
		if (ssrc == null)
			throw new NullPointerException("Need a valid SSRC instance");
		
		mSsrc = ssrc;
	}

	ArcImpl(SSRC ssrc, String url, String user, String password, TrustManager[] tms) 
			throws InitializationException {
		super(url, user, password, tms);
		if (ssrc == null)
			throw new NullPointerException("Need a valid SSRC instance");
		
		mSsrc = ssrc;
	}

	@Override
	public String getSessionId() {
		return mSsrc.getSessionId();
	}

	@Override
	public String getPublisherId() {
		return mSsrc.getPublisherId();
	}

	@Override
	public Integer getMaxPollResSize() {
		return mSsrc.getMaxPollResSize();
	}
	

	@Override
	public PollResult poll() 
			throws IfmapErrorResult, EndSessionException, IfmapException {
		PollRequest pollreq = mRequestFactory.createPollReq();
		pollreq.setSessionId(getSessionId());
		InputStream is = mMarshaller.marshalPollRequest(pollreq);
		InputStream resIs = doHttpRequest(is);
		PollResult pres = mUnmarshaller.unmarshalPollResult(resIs);
		return pres;
	}
}
