package de.fhhannover.inform.trust.ifmapj.identifier;

/**
 * Simple implementation of the {@link IdentifierFactory} interface.
 * 
 * @author aw
 *
 */
public class IdentifierFactoryImpl implements IdentifierFactory {

	@Override
	public AccessRequest createAr() {
		return createAr(null, null);
	}

	@Override
	public AccessRequest createAr(String name) {
		return createAr(name, null);
	}

	@Override
	public AccessRequest createAr(String name, String admDom) {
		AccessRequest ar = new AccessRequest();
		ar.setName(name);
		ar.setAdministrativeDomain(admDom);
		return ar;
	}

	@Override
	public Device createDev() {
		return createDev(null);
	}

	@Override
	public Device createDev(String name) {
		Device dev = new Device();
		dev.setName(name);
		return dev;
	}

	@Override
	public Identity createIdentity() {
		return createIdentity(null, null, null, null);
	}

	@Override
	public Identity createIdentity(IdentityType type, String name) {
		return createIdentity(type, name, null, null);
	}

	@Override
	public Identity createIdentity(IdentityType type, String name, String admDom) {
		return createIdentity(type, name, admDom, null);
	}

	@Override
	public Identity createIdentity(String name, String admDom, String otherTypeDef) {
		return createIdentity(IdentityType.other, name, admDom, otherTypeDef);
	}
	
	@Override
	public Identity createIdentity(IdentityType type, String name, String admDom,
			String otherTypeDef) {
		Identity id = new Identity();
		id.setType(type);
		id.setName(name);
		id.setAdministrativeDomain(admDom);
		id.setOtherTypeDefinition(otherTypeDef);
		return id;
	}
	
	@Override
	public IpAddress createIp4() {
		return createIp4(null, null);
	}

	@Override
	public IpAddress createIp4(String value) {
		return createIp4(value, null);
	}

	@Override
	public IpAddress createIp4(String value, String admDom) {
		return createIp(IpAddressType.IPv4, value, admDom);
	}

	@Override
	public IpAddress createIp6() {
		return createIp6(null, null);
	}

	@Override
	public IpAddress createIp6(String value) {
		return createIp6(value, null);
	}

	@Override
	public IpAddress createIp6(String value, String admDom) {
		return createIp(IpAddressType.IPv6, value, admDom);
	}
	
	@Override
	public IpAddress createIp(IpAddressType type, String value, String admDom) {
		IpAddress ip = new IpAddress();
		ip.setType(type);
		ip.setValue(value);
		ip.setAdministrativeDomain(admDom);
		return ip;
	}

	@Override
	public MacAddress createMac() {
		return createMac(null, null);
	}

	@Override
	public MacAddress createMac(String value) {
		return createMac(value, null);
	}

	@Override
	public MacAddress createMac(String value, String admDom) {
		MacAddress mac = new MacAddress();
		mac.setValue(value);
		mac.setAdministrativeDomain(admDom);
		return mac;
	}
}
